nvector._core.closest_point_on_great_circle — nvector 0.7.5 documentation

# nvector._core.closest_point_on_great_circle

`closest_point_on_great_circle`(path, n_EB_E)

  Returns closest point C on great circle path A to position B.

  Parameters
    path: tuple of 2 n-vectors of 3 x n arrays

      > 2 n-vectors of positions defining path A, decomposed in E.

      n_EB_E: 3 x m array

        n-vector(s) of position B to find the closest point to.

  Returns
    n_EC_E: 3 x max(m, n) array

      n-vector(s) of closest position C on great circle path A